*This code has been reviewed to ensure no confidential information has been disclosed. The Disclosure Review Board release number is DRB-BOO62-CED-20190627.

*create tract population density

use /redacted/pop_density.dta, clear
sort state county tract block_group
save /redacted/pop_density.dta, replace
by state county tract: egen tr_pop_2010=sum(tot_population_cen_2010)
by state county tract: egen tr_pop_12_16=sum(tot_population_acs_12_16)
by state county tract: egen tr_land_area=sum(land_area)
keep state county tract tr_pop_2010 tr_pop_12_16 tr_land_area
duplicates drop state county tract, force
save /redacted/pop_density_tr.dta, replace

use /redacted/pop_density.dta, clear
by state county: egen cty_pop_2010=sum(tot_population_cen_2010)
by state county: egen cty_pop_12_16=sum(tot_population_acs_12_16)
by state county: egen cty_land_area=sum(land_area)
keep state county cty_pop_2010 cty_pop_12_16 cty_land_area
duplicates drop state county, force
save /redacted/pop_density_cty.dta, replace



*create block group share of HHs with 1+ noncitizens, in poverty

use /redacted/acscit1216.dta, clear
gen noncit=1 if cit=="5"
replace noncit=0 if cit=="1" | cit=="2" | cit=="3" | cit=="4"
destring pov, force replace
replace pov=0 if pov==.
sort cmid
by cmid: egen noncit_hh=max(noncit)
by cmid: egen hpov=max(pov)
duplicates drop cmid, force
sort st cty tr bg
by st cty tr bg: egen noncit_hh_sh=sum(noncit_hh*wgt)
by st cty tr bg: egen hpov_sh=sum(hpov*wgt)
by st cty tr bg: egen sumwgt=sum(wgt)
replace noncit_hh_sh=noncit_hh_sh/sumwgt
replace hpov_sh=hpov_sh/sumwgt
duplicates drop st cty tr bg, force
keep st cty tr bg noncit_hh_sh hpov_sh
label var noncit_hh_sh "share of HHs in block group with 1+ noncitizens 2012-2016"
label var hpov_sh "share of HHs in block group in poverty 2012-2016"
save /redacted/acs1216_noncit_hh_sh.dta, replace

use /redacted/acscit1216.dta, clear
gen noncit=1 if cit=="5"
replace noncit=0 if cit=="1" | cit=="2" | cit=="3" | cit=="4"
destring pov, force replace
replace pov=0 if pov==.
sort cmid
by cmid: egen noncit_hh=max(noncit)
by cmid: egen hpov=max(pov)
duplicates drop cmid, force
sort st cty tr
by st cty tr: egen noncit_hh_tr_sh=sum(noncit_hh*wgt)
by st cty tr: egen hpov_tr_sh=sum(hpov*wgt)
by st cty tr: egen sumwgt=sum(wgt)
replace noncit_hh_tr_sh=noncit_hh_tr_sh/sumwgt
replace hpov_tr_sh=hpov_tr_sh/sumwgt
duplicates drop st cty tr, force
keep st cty tr noncit_hh_tr_sh hpov_tr_sh
label var noncit_hh_tr_sh "share of HHs in tract with 1+ noncitizens 2012-2016"
label var hpov_tr_sh "share of HHs in tract in poverty 2012-2016"
save /redacted/acs1216_noncit_hh_tr_sh.dta, replace

use /redacted/acscit1216.dta, clear
gen noncit=1 if cit=="5"
replace noncit=0 if cit=="1" | cit=="2" | cit=="3" | cit=="4"
destring pov, force replace
replace pov=0 if pov==.
sort cmid
by cmid: egen noncit_hh=max(noncit)
by cmid: egen hpov=max(pov)
duplicates drop cmid, force
sort st cty
by st cty: egen noncit_hh_cty_sh=sum(noncit_hh*wgt)
by st cty: egen hpov_cty_sh=sum(hpov*wgt)
by st cty: egen sumwgt=sum(wgt)
replace noncit_hh_cty_sh=noncit_hh_cty_sh/sumwgt
replace hpov_cty_sh=hpov_cty_sh/sumwgt
duplicates drop st cty, force
keep st cty noncit_hh_cty_sh hpov_cty_sh
label var noncit_hh_cty_sh "share of HHs in county with 1+ noncitizens 2012-2016"
label var hpov_cty_sh "share of HHs in county in poverty 2012-2016"
save /redacted/acs1216_noncit_hh_cty_sh.dta, replace

*block group vacancy rate

use /redacted/acscit_hh1216.dta, clear
gen vacant=1 if vacs~=""
replace vacant=0 if vacs==""
sort st cty tr bg
by st cty tr bg: egen vacant_sh=sum(vacant*hwgt)
by st cty tr bg: egen sumwgt=sum(hwgt)
replace vacant_sh=vacant_sh/sumwgt
duplicates drop st cty tr bg, force
keep st cty tr bg vacant_sh
label var vacant_sh "share of vacant HHs in block group 2012-2016"
save /redacted/acs1216_vac_hh_sh.dta, replace

use /redacted/acscit_hh1216.dta, clear
gen vacant=1 if vacs~=""
replace vacant=0 if vacs==""
sort st cty tr
by st cty tr: egen vacant_tr_sh=sum(vacant*hwgt)
by st cty tr: egen sumwgt=sum(hwgt)
replace vacant_tr_sh=vacant_tr_sh/sumwgt
duplicates drop st cty tr, force
keep st cty tr vacant_tr_sh
label var vacant_tr_sh "share of vacant HHs in tract 2012-2016"
save /redacted/acs1216_vac_hh_tr_sh.dta, replace

use /redacted/acscit_hh1216.dta, clear
gen vacant=1 if vacs~=""
replace vacant=0 if vacs==""
sort st cty
by st cty: egen vacant_cty_sh=sum(vacant*hwgt)
by st cty: egen sumwgt=sum(hwgt)
replace vacant_cty_sh=vacant_cty_sh/sumwgt
duplicates drop st cty, force
keep st cty vacant_cty_sh
label var vacant_cty_sh "share of vacant HHs in county 2012-2016"
save /redacted/acs1216_vac_hh_cty_sh.dta, replace

use /redacted/acs2017_hh.dta, clear
sort cmid
save /redacted/acs2017_hh.dta, replace

use /redacted/acs_cit2017.dta, clear
destring st, force gen(state)
destring cty, force gen(county)
destring tr, force gen(tract)
sort state county tract
merge state county tract using /redacted/pop_density_tr.dta
drop if _merge==2
drop _merge
sort state county
merge state county using /redacted/pop_density_cty.dta
drop if _merge==2
drop _merge
gen pop_density=log(tr_pop_12_16/tr_land_area)
replace pop_density=log(cty_pop_12_16/cty_land_area) if pop_density==.
gen pop_density_miss=1 if pop_density==.
replace pop_density_miss=0 if pop_density<.
replace pop_density=0 if pop_density==.
label var pop_density "log of ratio of 2012-2016 ACS tract population to land area"
drop state county tract tr_pop_2010 tr_pop_12_16 tr_land_area cty_pop_2010 cty_pop_12_16 cty_land_area
drop if pnum==.
sort st cty tr bg
merge st cty tr bg using /redacted/acs1216_noncit_hh_sh.dta
drop if _merge==2
drop _merge
sort st cty tr
merge st cty tr using /redacted/acs1216_noncit_hh_tr_sh.dta
drop if _merge==2
drop _merge
sort st cty
merge st cty using /redacted/acs1216_noncit_hh_cty_sh.dta
drop if _merge==2
drop _merge
sort st cty tr bg
merge st cty tr bg using /redacted/acs1216_vac_hh_sh.dta
drop if _merge==2
drop _merge
sort st cty tr
merge st cty tr using /redacted/acs1216_vac_hh_tr_sh.dta
drop if _merge==2
drop _merge
sort st cty
merge st cty using /redacted/acs1216_vac_hh_cty_sh.dta
drop if _merge==2
drop _merge
replace noncit_hh_sh=noncit_hh_tr_sh if noncit_hh_sh==.
replace noncit_hh_sh=noncit_hh_cty_sh if noncit_hh_sh==.
replace hpov_sh=hpov_tr_sh if hpov_sh==.
replace hpov_sh=hpov_cty_sh if hpov_sh==.
replace vacant_sh=vacant_tr_sh if vacant_sh==.
replace vacant_sh=vacant_cty_sh if vacant_sh==.
drop noncit_hh_tr_sh hpov_tr_sh noncit_hh_cty_sh hpov_cty_sh vacant_tr_sh vacant_cty_sh
sort cmid pnum
merge cmid using /redacted/acs2017_hh.dta
drop if _merge==2
drop _merge
destring bld, force replace
gen multi_unit=1 if bld>=4 & bld<=9
replace multi_unit=0 if multi_unit==.
gen single_unit=1 if bld>=2 & bld<=3
replace single_unit=0 if single_unit==.
gen other_residence=1 if bld==1 | bld==10
replace other_residence=0 if other_residence==.
gen move_1=1 if mvy>=2016 & mvy<=2017
replace move_1=0 if move_1==.
gen move_2_5=1 if mvy>=2012 & mvy<=2015
replace move_2_5=0 if move_2_5==.
sort cmid pnum
gen adult=1 if age>=18 & age<.
replace adult=0 if age<18
gen rela=1 if relationship<=1
replace rela=0 if relationship==2
gen age_0_4=1 if age<=4
replace age_0_4=0 if age>4 & age<.
gen age_5_17=1 if age>=5 & age<=17
replace age_5_17=0 if age<5 | (age>17 & age<.)
sort cmid pnum
by cmid: egen adult_cnt=sum(adult)
gen work=1 if wrk=="1" & adult==1
replace work=0 if work==.
by cmid: egen workadult_cnt=sum(work)
gen workadult=1 if adult_cnt==workadult_cnt & adult_cnt<.
replace workadult=0 if workadult==.
label var workadult "all adults 18+ worked in the last week"
drop adult_cnt work workadult_cnt
by cmid: egen age_0_4_rel=max(age_0_4*rela)
by cmid: egen age_0_4_nonrel=max(age_0_4*(1-rela))
by cmid: egen age_5_17_rel=max(age_5_17*rela)
by cmid: egen age_5_17_nonrel=max(age_5_17*(1-rela))
by cmid: egen adult_nonrel=max(adult*(1-rela))
label var age_0_4_rel "HH has at least one related child <5"
label var age_0_4_nonrel "HH has at least one unrelated child <5"
label var age_5_17_rel "HH has at least one related child 5-17"
label var age_5_17_nonrel "HH has at least one unrelated child 5-17"
label var adult_nonrel "HH has at least one adult 18+"
gen pass1=1 if pvs_verflg=="S" & pvs_pass=="01"
replace pass1=0 if pass1==.
label var pass1 "PVS pass 1 of Geosearch"
gen pass1_4=1 if pvs_verflg=="S" & (pvs_pass=="01" | pvs_pass=="02" | pvs_pass=="03" | pvs_pass=="04")
replace pass1_4=0 if pass1_4==.
label var pass1_4 "PVS pass 1-4 of Geosearch"
drop adult
replace tr="1" if tr==""
replace bg="1" if bg==""
egen blockgroup=group(st cty tr bg)
gen rsex=1 if fsex=="00"
replace rsex=0 if fsex~="00"
gen rage=1 if fage=="00" | fage=="10" | fage=="11" | fage=="12"
replace rage=0 if rage==.
gen rcit=1 if fcit=="00" | fcit=="10" | fcit=="20" | fcit=="30" | fcit=="35" | fcit=="60" | fcit=="70"
replace rcit=0 if rcit==.
gen work=1 if wrk=="1"
replace work=0 if work==.
gen jobsearch=1 if nwlk=="1"
replace jobsearch=0 if jobsearch==.
destring eng, force replace
replace eng=0 if lanx=="2"
gen engl=eng if relationship==0
sort cmid pnum
by cmid: egen english=min(engl)
*here we impute only English spoken at home for children age 0-4 in group quarters
replace english=0 if english==.
*here we calculate linguistic isolation, non-linguistic isolation, and all-English HHs
gen age_14p=1 if age>=14 & age<.
replace age_14p=0 if age<14
by cmid: egen lan_max=max(eng*age_14p)
gen only_eng_hh=1 if lan_max==0
replace only_eng_hh=0 if only_eng_hh==.
gen nli=1 if eng<=1 & age_14p==1
by cmid: egen non_ling_iso_hh=min(nli)
replace non_ling_iso_hh=0 if non_ling_iso_hh==. | only_eng_hh==1
gen li=1 if eng>1 & eng<. & age_14p==1
replace li=0 if eng<=1 & age_14p==1
by cmid: egen li_sum=sum(li)
by cmid: egen li_count=count(li)
gen ling_iso_hh=1 if li_sum==li_count & li_sum>0 & li_sum<.
replace ling_iso_hh=0 if ling_iso_hh==.
drop age_14p lan_max nli li li_sum li_count
gen femal=0 if sex=="1" & relationship==0
replace femal=1 if sex=="2" & relationship==0
by cmid: egen female=min(femal)
gen acsnc_arc=1 if agree==4
replace acsnc_arc=0 if agree==1
gen acsc_arnc=1 if agree==2
replace acsc_arnc=0 if agree==5
replace rsex=rsex*100
replace rage=rage*100
replace rcit=rcit*100
replace acsnc_arc=acsnc_arc*100
replace acsc_arnc=acsc_arnc*100
destring schl, force replace
gen schoo=schl if relationship==0
by cmid: egen school=min(schoo)
gen highschool=1 if school>=16 & school<=20
replace highschool=0 if highschool==.
gen bachelor=1 if school==21
replace bachelor=0 if bachelor==.
gen grad=1 if school>=22 & school<=24
replace grad=0 if grad==.
gen below_hs=1 if highschool==0 & bachelor==0 & grad==0
replace below_hs=0 if highschool==1 | bachelor==1 | grad==1
gen ar_cit=1 if num_cit==1
replace ar_cit=0 if ar_cit==.
gen ar_noncit=1 if num_cit==0
replace ar_noncit=0 if ar_noncit==.
gen ar_miss=1 if num_cit==.
replace ar_miss=0 if ar_miss==.  
gen relationship0=1 if relationship==0
replace relationship0=0 if relationship0==.
gen relationship1=1 if relationship==1
replace relationship1=0 if relationship1==.
gen relationship2=1 if relationship==2
replace relationship2=0 if relationship2==.
gen race1=1 if race==1
replace race1=0 if race1==.
gen race2=1 if race==2
replace race2=0 if race2==.
gen race3=1 if race==3
replace race3=0 if race3==.
gen race4=1 if race==4
replace race4=0 if race4==.
gen only_english=1 if english==0
replace only_english=0 if english>0 & english<.
gen english1=1 if english==1
replace english1=0 if english~=. & english1==.
gen english2=1 if english==2
replace english2=0 if english~=. & english2==.
gen english3=1 if english==3
replace english3=0 if english~=. & english3==.
gen english4=1 if english==4
replace english4=0 if english~=. & english4==.
gen sr=1 if mode=="1" | mode=="6"
replace sr=0 if mode=="2" | mode=="3" | mode=="5"
gen hinc_25=1 if hinc>0 & hinc<=25000
replace hinc_25=0 if hinc_25==.
gen hinc_50=1 if hinc>25000 & hinc<=50000
replace hinc_50=0 if hinc_50==.
gen hinc_75=1 if hinc>50000 & hinc<=75000
replace hinc_75=0 if hinc_75==.
gen hinc_100=1 if hinc>75000 & hinc<=100000
replace hinc_100=0 if hinc_100==.
gen hinc_100p=1 if hinc>100000 & hinc<.
replace hinc_100p=0 if hinc_100p==.
gen hinc_below_25=1 if hinc_25==0 & hinc_50==0 & hinc_75==0 & hinc_100==0 & hinc_100p==0
replace hinc_below_25=0 if hinc_25==1 | hinc_50==1 | hinc_75==1 | hinc_100==1 | hinc_100p==1
gen cit_noncit=1 if ar_cit==1
replace cit_noncit=0 if ar_noncit==1
gen cit_miss=1 if ar_cit==1
replace cit_miss=0 if num_cit==.
gen noncit_miss=1 if ar_noncit==1
replace noncit_miss=0 if num_cit==.
by cmid: egen acs_pop=count(pnum)
gen lpop=log(acs_pop)
gen lpop_sq=lpop^2
gen cit_agree1=1 if agree==1
replace cit_agree1=0 if agree~=1
by cmid: egen cit_agree1_=sum(cit_agree1)
by cmid: egen cnt=count(cit_agree1)
gen all_cit_hh=1 if cnt==cit_agree1_ & cnt>0 & cnt<.
replace all_cit_hh=0 if all_cit_hh==.
gen marrie=1 if mar=="1" & relationship==0
replace marrie=0 if marrie==. & relationship==0
sort cmid
by cmid: egen married=min(marrie)
drop marrie cit_agree1 cit_agree1_
gen owned=1 if ten=="1" | ten=="2"
replace owned=0 if owned==.
sort cmid pnum
save /redacted/acs_cit2017.dta, replace

use /redacted/acs2017_pers_repw.dta, clear
sort cmid pnum
save /redacted/acs2017_pers_repw.dta, replace

use /redacted/acs_cit2017.dta, clear
merge cmid pnum  using /redacted/acs2017_pers_repw.dta
drop _merge
sort cmid pnum

global path "/redacted/acs2017_regs_20190312.xls"
global vars1 "relationship1 relationship2 race2 race3 race4 non_ling_iso_hh ling_iso_hh pass1_4 sr female highschool bachelor grad work jobsearch hinc_25 hinc_50 hinc_75 hinc_100 hinc_100p hpov_sh noncit_hh_sh"
global vars2 "relationship1 relationship2 race2 race3 race4 non_ling_iso_hh ling_iso_hh pass1 sr female highschool bachelor grad work jobsearch hinc_25 hinc_50 hinc_75 hinc_100 hinc_100p hpov_sh noncit_hh_sh"

log using /redacted/20190312_itemresponsereg.log, replace
gen nrage=100-rage
gen nrcit=100-rcit

svyset[pw=pwgt], vce(brr) brrweight(repw1-repw80) fay(.5)mse

reg nrage $vars1 [fw=pwgt] if ar_cit==1, cluster(cmid)
outreg2 using $path, nocons dec(3) noas replace
svy: mean nrage if e(sample)
reg nrage $vars2 [fw=pwgt] if ar_cit==1, cluster(blockgroup)
outreg2 using $path, nocons dec(3) noas append
sum female if e(sample)

reg nrage $vars1 [fw=pwgt] if ar_noncit==1, cluster(cmid)
outreg2 using $path, nocons dec(3) noas append
svy: mean nrage if e(sample)
reg nrage $vars2 [fw=pwgt] if ar_noncit==1, cluster(blockgroup)
outreg2 using $path, nocons dec(3) noas append
sum female if e(sample)

reg nrcit $vars1 [fw=pwgt] if ar_cit==1, cluster(cmid)
outreg2 using $path, nocons dec(3) noas append
svy: mean nrcit if e(sample)
reg nrcit $vars2 [fw=pwgt] if ar_cit==1, cluster(blockgroup)
outreg2 using $path, nocons dec(3) noas append
sum female if e(sample)

reg nrcit $vars1 [fw=pwgt] if ar_noncit==1, cluster(cmid)
outreg2 using $path, nocons dec(3) noas append
svy: mean nrcit if e(sample)
reg nrcit $vars2 [fw=pwgt] if ar_noncit==1, cluster(blockgroup)
outreg2 using $path, nocons dec(3) noas append
sum female if e(sample)

gen age_disc = .
replace age_disc = 0 if rage==100 & fage=="00" & abs(birthyear-dby)<2
replace age_disc = 1 if rage==100  & fage=="00" & abs(birthyear-dby)>=2
tab age_disc, miss

reg age_disc $vars1 [fw=pwgt] if ar_cit==1, cluster(cmid)
outreg2 using $path, nocons dec(3) noas append
svy: mean age_disc if e(sample)
reg age_disc $vars2 [fw=pwgt] if ar_cit==1, cluster(blockgroup)
outreg2 using $path, nocons dec(3) noas append
sum female if e(sample)

reg age_disc $vars1 [fw=pwgt] if ar_noncit==1, cluster(cmid)
outreg2 using $path, nocons dec(3) noas append
svy: mean age_disc if e(sample)
reg age_disc $vars2 [fw=pwgt] if ar_noncit==1, cluster(blockgroup)
outreg2 using $path, nocons dec(3) noas append
sum female if e(sample)

reg acsnc_arc $vars1 [fw=pwgt], cluster(cmid)
outreg2 using $path, nocons dec(3) noas append
svy: mean acsnc_arc if e(sample)
reg acsnc_arc $vars2 [fw=pwgt], cluster(blockgroup)
outreg2 using $path, nocons dec(3) noas append
sum female if e(sample)

reg acsc_arnc $vars1 [fw=pwgt], cluster(cmid)
outreg2 using $path, nocons dec(3) noas append
svy: mean acsc_arnc if e(sample)
reg acsc_arnc $vars2 [fw=pwgt], cluster(blockgroup)
outreg2 using $path, nocons dec(3) noas append
sum female if e(sample)

* Diff in Diff Table

* For now missing num_cit is dropped from analysis, also dropping if ar age is missing
drop if num_cit==.
drop if birthyear==.
assert dby~=. & acs_cit~=.
gen goodres_cit=100 if rcit==100 & num_cit==acs_cit
replace goodres_cit=0 if goodres_cit==.
label var goodres_cit "100 if responded and ar and acs are both citizen (0 if any missing)"
gen goodres_age=100 if rage==100 &  abs(birthyear-dby)<2
replace goodres_age=0 if goodres_age==. 
label var goodres_age "100 if responded and ar and acs birth years are less than 2 yrs apart and nonmissing"
gen d_goodres_citage= goodres_cit-goodres_age

* alternative version
gen goodres_cit_v2=100 if fcit=="00" & num_cit==acs_cit
replace goodres_cit_v2=0 if goodres_cit_v2==.
label var goodres_cit_v2 "100 if fcit=00 and ar and acs are both citizen (0 if any missing)"
gen goodres_age_v2=100 if fage=="00" &  abs(birthyear-dby)<2
replace goodres_age_v2=0 if goodres_age_v2==. 
label var goodres_age_v2 "100 if responded and ar and acs birth years are less than 2 yrs apart and nonmissing"
gen d_goodres_citage_v2= goodres_cit_v2-goodres_age_v2

* groups are going to be individual citizens and non-citizens by num_cit. 
gen num_citx=1 if num_cit==1
replace num_citx=0 if num_cit==0
assert num_citx~=.

* quick diff-in-diff
table num_citx [fw=pwgt], c(mean goodres_cit mean goodres_age mean d_goodres_citage)
table num_citx [fw=pwgt], c(mean goodres_cit_v2 mean goodres_age_v2 mean d_goodres_citage_v2)

* counts for disclosure
table num_citx, c(n goodres_cit n goodres_age n d_goodres_citage) row col
tab num_citx goodres_cit if goodres_cit==100
tab num_citx goodres_age if goodres_age==100

* Bootstrapped diff-in-diff
svyset[pw=pwgt], vce(brr) brrweight(repw1-repw80) fay(.5)mse

svy: mean goodres_cit_v2 goodres_age_v2 d_goodres_citage_v2 if num_citx==0	
svy: mean goodres_cit_v2 goodres_age_v2 d_goodres_citage_v2 if num_citx==1

*****************************************************************************
* OB decomposition Table (diff in diff)

svyset[pw=pwgt], vce(bootstrap) bsrweight(repw1-repw80) mse

* quick ob decomposition

oaxaca d_goodres_citage_v2 $vars1 [fw=pwgt], by(num_citx) weight(0) categorical(relationship0 relationship1 relationship2, race1 race2 race3 race4, only_eng_hh non_ling_iso_hh ling_iso_hh, below_hs highschool bachelor grad, hinc_below_25 hinc_25 hinc_50 hinc_75 hinc_100 hinc_100p)
oaxaca d_goodres_citage_v2 $vars2 [fw=pwgt], by(num_citx) weight(0) categorical(relationship0 relationship1 relationship2, race1 race2 race3 race4, only_eng_hh non_ling_iso_hh ling_iso_hh, below_hs highschool bachelor grad, hinc_below_25 hinc_25 hinc_50 hinc_75 hinc_100 hinc_100p)

* Bootstrapped ob decomposition
eststo ob2: svy: bootstrap: oaxaca d_goodres_citage_v2 $vars1, by(num_citx) weight(0) categorical(relationship0 relationship1 relationship2, race1 race2 race3 race4, only_eng_hh non_ling_iso_hh ling_iso_hh, below_hs highschool bachelor grad, hinc_below_25 hinc_25 hinc_50 hinc_75 hinc_100 hinc_100p)

log close
