*This code has been reviewed to ensure no confidential information has been disclosed. The Disclosure Review Board release number is DRB-BOO62-CED-20190627.

*******************************************************************************************
/*
* LASSO AND PCA TESTING 

* Input files:
acs_cen_response_regs_addvars.dta

acs_cit2010.dta (linguistically isolated HH variable 20190312.do)
acs_cit2010_allvars.dta 
unit_resp_regs_2010.dta
*/
*******************************************************************************************

* baseline dataset
use acs_cen_response_regs_addvars.dta, clear

* merging 3 additional files for additional regressors
preserve
use cmid only_eng_hh non_ling_iso_hh ling_iso_hh using acs_cit2010.dta, replace
by cmid: keep if _n==1
tempfile lingvars
save `lingvars', replace
restore
merge 1:1 cmid using `lingvars', keep(master match) nogen
merge 1:1 cmid using acs_cit2010_allvars.dta, keepusing(*_d *_c) keep(match) nogen
merge 1:1 cmid using unit_resp_regs_2010.dta, keep(match) keepusing(noncit_hh_sh hpov_sh workadult pop_density pop_density_miss vacant_sh age_0_4_rel age_0_4_nonrel age_5_17_rel age_5_17_nonrel adult_nonrel move_1 move_2_5 multi_unit single_unit other_residence owned female_mar female_unmar male_mar male_unmar)


foreach v in noncit_hh_sh hpov_sh workadult pop_density pop_density_miss vacant_sh age_0_4_rel age_0_4_nonrel age_5_17_rel age_5_17_nonrel adult_nonrel move_1 move_2_5 multi_unit single_unit other_residence owned female_mar female_unmar male_mar male_unmar {
qui unique `v'
dis "`v' " _col(20) `r(sum)'
if `r(sum)'<=2 {
rename `v' `v'_d
}
else if `r(sum)'>2 {
rename `v' `v'_c
}
}
gen response1=responsevar_acs-responsevar_cen
gen race1=1 if race2==0 & race3==0 & race4==0
replace race1=0 if race2==1 | race3==1 | race4==1
gen age_below_25=1 if age_25_34==0 & age_35_44==0 & age_45_54==0 & age_55_64==0 & age_65p==0
replace age_below_25=0 if age_25_34==1 | age_35_44==1 | age_45_54==1 | age_55_64==1 | age_65p==1
gen below_hs=1 if highschool==0 & bachelor==0 & grad==0
replace below_hs=0 if highschool==1 | bachelor==1 | grad==1
gen hinc_below_25=1 if hinc_25==0 & hinc_50==0 & hinc_75==0 & hinc_100==0 & hinc_100p==0
replace hinc_below_25=0 if hinc_25==1 | hinc_50==1 | hinc_75==1 | hinc_100==1 | hinc_100p==1
gen only_english=1 if english1==0 & english2==0 & english3==0 & english4==0
replace only_english=0 if english1==1 | english2==1 | english3==1 | english4==1
replace hwage=0 if hwage==.
replace classofworker=0 if classofworker==.
tostring occupation, replace format(%04.0f)
gen occ1d=substr(occupation,1,1)
replace occ1d="10" if occ1d=="."
label var occ1d 	"1 digit occupation, coded 10 if missing" 
foreach catvar in yasamecty worksamet healthcov restaxind classofworker occ1d {
rename `catvar' `catvar'_d
cap destring `catvar', replace
}		
svyset[pw=wgt], vce(bootstrap) bsrweight(repw1-repw80) mse
replace response=response*100
gen cit=1 if noncit_h==0
replace cit=0 if noncit_h==1
* drop variables with more than 20 categories
ds *_d
foreach v in `r(varlist)' {
qui unique `v'
dis "`v' " _col(20) `r(sum)'
if `r(sum)'>=20 {
drop `v'
}
}
* get new acs continuous and categorical variables ("refd") here
ds *_c
local newacs_contvars `r(varlist)'
ds *_d 
local newacs_catvars `r(varlist)'
macro list _newacs_contvars _newacs_catvars
* PCA requires categorical variables coded differently
ds *_d 
foreach catvar in `r(varlist)' {
qui tab `catvar', gen(d_`catvar')
}
ds d_*
local newacs_catvars_pca `r(varlist)'

* final set of variables
global rhs "lpop lpop_sq female race2 race3 race4 age_25_34 age_35_44 age_45_54 age_55_64 age_65p highschool bachelor grad hinc_25 hinc_50 hinc_75 hinc_100 hinc_100p work jobsearch english1 english2 english3 english4 non_ling_iso_hh ling_iso_hh"

* keep consistent sample (for pca)
qui oaxaca response $rhs [pw=wgt], by(length) weight(0)
keep if e(sample)==1

global universe $rhs `newacs_contvars' `newacs_catvars_pca'
local univsize: list sizeof global universe
macro list _univsize



************************************************************************************************************************
*  lasso using ebic
lasso2 response $rhs `newacs_contvars' i.(`newacs_catvars') if length==1
lasso2, lic(ebic) postest
local lassorhs1 `e(selected)'
macro list _lassorhs1
* extract categorical variables
foreach v in `lassorhs1' {
	if strpos("`v'", ".") local cleanthese `cleanthese' `v'
	else local dropthese `dropthese' `v'
}
* clean names and generate appropriate names
local cleancatnames ""
foreach v in `cleanthese' {
local t=subinstr("`v'", ".", "",.)
local cleanv="d`t'"
cap gen `cleanv'=`v'
local cleancatnames `cleancatnames' `cleanv'
}
global rhsclean "`dropthese' `cleancatnames'"
macro list rhsclean
local size: list sizeof global rhsclean
macro list _size
eststo ob_lassoebic: svy: bootstrap: oaxaca response $rhsclean, by(length) weight(0) relax
macro drop _lassorhs1 rhsclean _cleanthese _dropthese




************************************************************************************************************************
* lasso using cross validation
cvlasso response $rhs `newacs_contvars' i.(`newacs_catvars') if length==1
cvlasso, lopt postest
local lassorhs1 `e(selected)'
macro list _lassorhs1
* extract categorical variables
foreach v in `lassorhs1' {
	if strpos("`v'", ".") local cleanthese `cleanthese' `v'
	else local dropthese `dropthese' `v'
}
* clean names and generate appropriate names
local cleancatnames ""
foreach v in `cleanthese' {
local t=subinstr("`v'", ".", "",.)
local cleanv="d`t'"
cap gen `cleanv'=`v'
local cleancatnames `cleancatnames' `cleanv'
}
global rhsclean "`dropthese' `cleancatnames'"
macro list rhsclean
local size: list sizeof global rhsclean
macro list _size
eststo ob_lassocv: svy: bootstrap: oaxaca response $rhsclean, by(length) weight(0) relax
macro drop _lassorhs1 rhsclean _cleanthese _dropthese



************************************************************************************************************************
* lasso using aic
lasso2 response $rhs `newacs_contvars' i.(`newacs_catvars') if length==1
lasso2, lic(aic) postest
local lassorhs1 `e(selected)'
macro list _lassorhs1
* extract categorical variables
foreach v in `lassorhs1' {
	if strpos("`v'", ".") local cleanthese `cleanthese' `v'
	else local dropthese `dropthese' `v'
}
* clean names and generate appropriate names
local cleancatnames ""
foreach v in `cleanthese' {
local t=subinstr("`v'", ".", "",.)
local cleanv="d`t'"
cap gen `cleanv'=`v'
local cleancatnames `cleancatnames' `cleanv'
}
global rhsclean "`dropthese' `cleancatnames'"
macro list rhsclean
local size: list sizeof global rhsclean
macro list _size
eststo ob_lassoaic: svy: bootstrap: oaxaca response $rhsclean, by(length) weight(0) relax
macro drop _lassorhs1 rhsclean _cleanthese _dropthese
************************************************************************************************************************

************************************************************************************************************************
* PCA - 20 components
pca $rhs `newacs_contvars' `newacs_catvars_pca', components(20)
qui predict C*
eststo ob_pca20: svy: bootstrap: oaxaca response C*, by(length) weight(0) relax
drop C*
************************************************************************************************************************

 
************************************************************************************************************************
* PCA - 50 components
pca $rhs `newacs_contvars' `newacs_catvars_pca', components(50)
qui predict C*
eststo ob_pca50: svy: bootstrap: oaxaca response C*, by(length) weight(0) relax
drop C*
************************************************************************************************************************


************************************************************************************************************************
* PCA - 100 components
pca $rhs `newacs_contvars' `newacs_catvars_pca', components(100)
qui predict C*
eststo ob_pca100: svy: bootstrap: oaxaca response C*, by(length) weight(0) relax
drop C*
************************************************************************************************************************


************************************************************************************************************************
************************************************************************************************************************
************************************************************************************************************************
* TABLE A1
esttab ob_lassoebic ob_lassocv ob_lassoaic ob_pca20 ob_pca50 ob_pca100, se keep(difference explained unexplained) mtitle(lassoebic lassocv lassoaic pca20 pca50 pca100)
************************************************************************************************************************
************************************************************************************************************************
************************************************************************************************************************

